DropdownMode enum

Controls how the dropdown items are presented to the user.

  • DropdownMode.overlay: The default mode, shows items in an overlay positioned relative to the field (classic dropdown).
  • DropdownMode.bottomSheet: Shows items in a modal bottom sheet, better suited for mobile experiences with many items.
Inheritance
Available extensions

Values

overlay → const DropdownMode

Show items in an overlay dropdown (default).

bottomSheet → const DropdownMode

Show items in a modal bottom sheet.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DropdownMode>
A constant List of the values in this enum, in order of their declaration.