MultiSelectController<T> class

implementation of the MultiSelectController class.

Inheritance

Constructors

MultiSelectController()

Properties

disabledOptions → List<ValueItem<T>>
get disabled options
no setter
enabledOptions → List<ValueItem<T>>
get enabled options
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
isDisposed → bool
no setter
isDropdownOpen → bool
get is dropdown open
no setter
options → List<ValueItem<T>>
get options
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedOptions → List<ValueItem<T>>
get selected options
no setter
value ↔ _MultiSelectController<T>
The current value stored in this notifier.
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
addSelectedOption(ValueItem<T> option) → void
add selected option MultiSelectController is used to add selected option.
clearAllSelection() → void
Clear the selected options. MultiSelectController is used to clear the selected options.
clearSelection(ValueItem<T> option) → void
clear specific selected option MultiSelectController is used to clear specific selected option.
dispose() → void
set the dispose method.
override
hideDropdown() → void
hide dropdown MultiSelectController is used to hide dropdown.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setDisabledOption(ValueItem<T> disabledOption) → void
setDisabledOption method MultiSelectController is used to set disabled option.
setDisabledOptions(List<ValueItem<T>> disabledOptions) → void
set disabled options MultiSelectController is used to set disabled options.
setOptions(List<ValueItem<T>> options) → void
set options MultiSelectController is used to set options.
setSelectedOptions(List<ValueItem<T>> options) → void
select the options MultiSelectController is used to select the options.
showDropdown() → void
show dropdown MultiSelectController is used to show dropdown.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited